@@ -31,7 +31,15 @@ use constant {
 };
 use constant ATTR_MSG_AUTH_ZERO => pack('C C', ATTR_MSG_AUTH, ATTR_MSG_AUTH_LEN) . ("\x0" x (ATTR_MSG_AUTH_LEN - 2));
 
-my %IS_REPLY   = map { $_ => 1 } (ACCESS_ACCEPT, ACCESS_REJECT, DISCONNECT_ACCEPT, DISCONNECT_REJECT, COA_ACCEPT, COA_REJECT);
+my %IS_REPLY = map { $_ => 1 } (
+    ACCESS_ACCEPT,
+    ACCESS_CHALLENGE,
+    ACCESS_REJECT,
+    DISCONNECT_ACCEPT,
+    DISCONNECT_REJECT,
+    COA_ACCEPT,
+    COA_REJECT
+);
 my %IS_REQUEST = map { $_ => 1 } (ACCESS_REQUEST, ACCOUNTING_REQUEST, DISCONNECT_REQUEST, COA_REQUEST);
 
 my %IS_ACCOUNTING = map { $_ => 1 } (ACCOUNTING_REQUEST, ACCOUNTING_RESPONSE);
